%define anolis_release 1
%bcond_with deprecated

Name:    bluez
Version: 5.69
Release: %{anolis_release}%{?dist}
Summary: Bluetooth utilities
License: GPLv2+
URL:     http://www.bluez.org/
Source0: http://www.kernel.org/pub/linux/bluetooth/%{name}-%{version}.tar.xz
Patch0:  bluez-5.69-linkage.patch

BuildRequires: make
BuildRequires: /usr/bin/rst2man
BuildRequires: cups-devel
BuildRequires: readline-devel
BuildRequires: pkgconfig(dbus-1) >= 1.10
BuildRequires: pkgconfig(ell) >= 0.39
BuildRequires: pkgconfig(glib-2.0) >= 2.28
BuildRequires: pkgconfig(gthread-2.0) >= 2.16
BuildRequires: pkgconfig(json-c) >= 0.13
BuildRequires: pkgconfig(libical)
BuildRequires: pkgconfig(libudev) >= 172
BuildRequires: pkgconfig(systemd)

Requires: dbus >= 1.10
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
Utilities for use in Bluetooth applications:
	- avinfo
	- bluemoon
	- bluetoothctl
	- bluetoothd
	- btattach
	- btmon
	- hex2hcd
	- l2ping
	- l2test
	- mpris-proxy
	- rctest

The BLUETOOTH trademarks are owned by Bluetooth SIG, Inc., U.S.A.

%package cups
Summary: CUPS printer backend for Bluetooth printers
Requires: bluez = %{EVR}
Requires: cups

%description cups
This package provides the CUPS backend

%if %{with deprecated}
%package deprecated
Summary: Deprecated Bluetooth applications
Requires: bluez = %{EVR}
Obsoletes: bluez < 5.55

%description deprecated
Bluetooth applications that have bee deprecated by upstream. They have been
replaced by funcationality in the core bluetoothctl and will eventually
be dropped by upstream. Utilities include:
	- ciptool
	- gatttool
	- hciattach
	- hciconfig
	- hcidump
	- hcitool
	- rfcomm
	- sdptool
%endif

%package libs
Summary: Libraries for use in Bluetooth applications

%description libs
Libraries for use in Bluetooth applications.

%package libs-devel
Summary: Development libraries for Bluetooth applications
Requires: bluez-libs = %{EVR}

%description libs-devel
bluez-libs-devel provides development libraries and headers for
use in Bluetooth applications.

%package hid2hci
Summary: Put HID proxying bluetooth HCI's into HCI mode
Requires: bluez = %{EVR}

%description hid2hci
Most allinone PC's and bluetooth keyboard / mouse sets which include a
bluetooth dongle, ship with a so called HID proxying bluetooth HCI.
The HID proxying makes the keyboard / mouse show up as regular USB HID
devices (after connecting using the connect button on the device + keyboard),
which makes them work without requiring any manual configuration.

The bluez-hid2hci package provides the hid2hci utility and udev rules to
automatically switch supported Bluetooth devices into regular HCI mode.

Install this package if you want to use the bluetooth function of the HCI
with other bluetooth devices like for example a mobile phone.

Note that after installing this package you will first need to pair your
bluetooth keyboard and mouse with the bluetooth adapter before you can use
them again. Since you cannot use your bluetooth keyboard and mouse until
they are paired, this will require the use of a regular (wired) USB keyboard
and mouse.

%package mesh
Summary: Bluetooth mesh
Requires: bluez = %{EVR}
Requires: bluez-libs = %{EVR}

%description mesh
Services for bluetooth mesh

%package obexd
Summary: Object Exchange daemon for sharing content
Requires: bluez = %{EVR}
Requires: bluez-libs = %{EVR}

%description obexd
Object Exchange daemon for sharing files, contacts etc over bluetooth

%package doc
Summary: Doc files for Bluetooth applications
Requires: bluez = %{EVR}
BuildArch: noarch

%description doc
Doc files for Bluetooth applications

%prep
%autosetup -p1

%build
%configure --enable-tools \
           --enable-library \
           --disable-optimization \
           --enable-sixaxis \
           --enable-cups \
           --enable-nfc \
           --enable-mesh \
           --enable-hid2hci \
           --enable-testing \
%if %{with deprecated}
           --enable-deprecated \
%endif
           --with-systemdsystemunitdir=%{_unitdir} \
           --with-systemduserunitdir=%{_userunitdir}

%make_build

%install
%make_install

%if %{with deprecated}
install -m0755 attrib/gatttool %{buildroot}%{_bindir}
%endif

install -m0755 tools/avinfo %{buildroot}%{_bindir}
install -m0755 tools/btmgmt %{buildroot}%{_bindir}

if test -d %{buildroot}%{_libdir}/cups ; then
	install -D -m0755 %{buildroot}%{_libdir}/cups/backend/bluetooth %{buildroot}%_cups_serverbin/backend/bluetooth
	rm -rf %{buildroot}%{_libdir}/cups
fi

rm -f %{buildroot}/%{_sysconfdir}/udev/*.rules %{buildroot}%{_udevrulesdir}/*.rules
mkdir -p %{buildroot}/%{_udevrulesdir}
install -p -m0644 tools/hid2hci.rules %{buildroot}/%{_udevrulesdir}/97-hid2hci.rules
install -d -m0755 %{buildroot}/%{_localstatedir}/lib/bluetooth
install -d -m0755 %{buildroot}/%{_localstatedir}/lib/bluetooth/mesh

mkdir -p %{buildroot}/%{_libdir}/bluetooth/
mkdir -p %{buildroot}%{_sysconfdir}/bluetooth
install -p -m0644 src/main.conf %{buildroot}%{_sysconfdir}/bluetooth/main.conf
install -p -m0644 mesh/mesh-main.conf %{buildroot}%{_sysconfdir}/bluetooth/mesh-main.conf
sed -i 's/#\[Policy\]$/\[Policy\]/; s/#AutoEnable=false/AutoEnable=true/' %{buildroot}/%{_sysconfdir}/bluetooth/main.conf

install emulator/btvirt %{buildroot}/%{_libexecdir}/bluetooth/

%check
%make_build check

%post
%systemd_post bluetooth.service

%preun
%systemd_preun bluetooth.service

%postun
%systemd_postun_with_restart bluetooth.service

%post hid2hci
/sbin/udevadm trigger --subsystem-match=usb

%post mesh
%systemd_user_post bluetooth-mesh.service

%preun mesh
%systemd_user_preun bluetooth-mesh.service

%post obexd
%systemd_user_post obex.service

%preun obexd
%systemd_user_preun obex.service

%files
%dir %{_sysconfdir}/bluetooth
%config(noreplace) %{_sysconfdir}/bluetooth/main.conf
%{_bindir}/avinfo
%{_bindir}/bluemoon
%{_bindir}/bluetoothctl
%{_bindir}/btattach
%{_bindir}/btmgmt
%{_bindir}/btmon
%{_bindir}/hex2hcd
%{_bindir}/l2ping
%{_bindir}/l2test
%{_bindir}/mpris-proxy
%{_bindir}/rctest
%dir %{_libexecdir}/bluetooth
%{_libexecdir}/bluetooth/bluetoothd

%{_libdir}/bluetooth/
%{_localstatedir}/lib/bluetooth
%{_datadir}/dbus-1/system.d/bluetooth.conf
%{_datadir}/dbus-1/system-services/org.bluez.service
%{_datadir}/zsh/site-functions/_bluetoothctl
%{_unitdir}/bluetooth.service

%{_mandir}/man1/bluetoothctl-mgmt.1.*            
%{_mandir}/man1/bluetoothctl-monitor.1.*            
%{_mandir}/man1/btmgmt.1.*
%{_mandir}/man1/btattach.1.*
%{_mandir}/man1/btmon.1.*
%{_mandir}/man1/l2ping.1.*
%{_mandir}/man1/rctest.1.*
%{_mandir}/man8/bluetoothd.8.*
%license COPYING

%if %{with deprecated}
%files deprecated
%{_bindir}/ciptool
%{_bindir}/gatttool
%{_bindir}/hciattach
%{_bindir}/hciconfig
%{_bindir}/hcidump
%{_bindir}/hcitool
%{_bindir}/meshctl
%{_bindir}/rfcomm
%{_bindir}/sdptool
%{_mandir}/man1/ciptool.1.*
%{_mandir}/man1/hciattach.1.*
%{_mandir}/man1/hciconfig.1.*
%{_mandir}/man1/hcidump.1.*
%{_mandir}/man1/hcitool.1.*
%{_mandir}/man1/rfcomm.1.*
%{_mandir}/man1/sdptool.1.*
%endif

%files libs
%{_libdir}/libbluetooth.so.3
%{_libdir}/libbluetooth.so.3.*
%license COPYING

%files libs-devel
%{_bindir}/isotest
%{_mandir}/man1/isotest.1.*
%{_libdir}/libbluetooth.so
%{_includedir}/bluetooth
%{_libdir}/pkgconfig/bluez.pc
%dir %{_libexecdir}/bluetooth
%{_libexecdir}/bluetooth/btvirt
%doc doc/*txt

%files cups
%_cups_serverbin/backend/bluetooth

%files hid2hci
%{_prefix}/lib/udev/hid2hci
%{_udevrulesdir}/97-hid2hci.rules
%{_mandir}/man1/hid2hci.1*

%files mesh
%config(noreplace) %{_sysconfdir}/bluetooth/mesh-main.conf
%{_bindir}/mesh-cfgclient
%{_bindir}/mesh-cfgtest
%{_datadir}/dbus-1/system.d/bluetooth-mesh.conf
%{_datadir}/dbus-1/system-services/org.bluez.mesh.service
%{_libexecdir}/bluetooth/bluetooth-meshd
%{_unitdir}/bluetooth-mesh.service
%{_localstatedir}/lib/bluetooth/mesh
%{_mandir}/man8/bluetooth-meshd.8*

%files obexd
%{_libexecdir}/bluetooth/obexd
%{_datadir}/dbus-1/services/org.bluez.obex.service
%{_userunitdir}/obex.service

%files doc
%doc ChangeLog AUTHORS

%changelog
* Sat Aug 26 2023 Funda Wang <fundwang@yeah.net> - 5.69-1
- New version 5.69

* Sat Apr 15 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 5.66-2
- Refactor the specfile

* Thu Dec 29 2022 Funda Wang <fundwang@yeah.net> - 5.66-1
- New version 5.66

* Thu Sep 1 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 5.65-1
- update to 5.65

* Fri Apr 8 2022 Zhongling He <zhonglingh@linux.alibaba.com> - 5.64-1
- Init package from upstream v5.64
